@@ -11,8 +11,8 @@ an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express o
 specific language governing permissions and limitations under the License.
 """
 
-import os
 import django
+from django.conf import settings
 
 from blueapps.core.handler.wsgi import BkWSGIHandler
 from blueapps.opentelemetry.metrics.server import start_metrics_http_server
@@ -28,7 +28,7 @@ def get_wsgi_application():
     """
     django.setup(set_prefix=False)
 
-    if os.getenv("ENABLE_METRICS", False):
+    if "blueapps.opentelemetry.instrument_app" in set(settings.INSTALLED_APPS):
         start_metrics_http_server()
 
     return BkWSGIHandler()
